from sqlalchemy.orm import Session
from app.models.product import Category
from app.models.inventory import Location, LocationType

def init_db(db: Session) -> None:
    """Initialize database with default data"""
    
    # Check if we already have data
    if db.query(Category).first():
        return  # Database already initialized
    
    # Create default categories
    default_categories = [
        Category(name="General", description="General products"),
        Category(name="Electronics", description="Electronic products"),
        Category(name="Office Supplies", description="Office supplies and stationery"),
        Category(name="Furniture", description="Furniture items"),
    ]
    
    db.add_all(default_categories)
    
    # Create default locations
    default_locations = [
        Location(name="Main Warehouse", type=LocationType.WAREHOUSE, 
                description="Main storage warehouse"),
        Location(name="Store Front", type=LocationType.STORE, 
                description="Main store front"),
    ]
    
    db.add_all(default_locations)
    
    db.commit()